/*************************************************************************

"FreePastry" Peer-to-Peer Application Development Substrate 

Copyright 2002, Rice University. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

- Neither  the name  of Rice  University (RICE) nor  the names  of its
contributors may be  used to endorse or promote  products derived from
this software without specific prior written permission.

This software is provided by RICE and the contributors on an "as is"
basis, without any representations or warranties of any kind, express
or implied including, but not limited to, representations or
warranties of non-infringement, merchantability or fitness for a
particular purpose. In no event shall RICE or contributors be liable
for any direct, indirect, incidental, special, exemplary, or
consequential damages (including, but not limited to, procurement of
substitute goods or services; loss of use, data, or profits; or
business interruption) however caused and on any theory of liability,
whether in contract, strict liability, or tort (including negligence
or otherwise) arising in any way out of the use of this software, even
if advised of the possibility of such damage.

********************************************************************************/
/*
 *  Created on Apr 6, 2005
 */
package rice.environment.logging.simple;

import java.io.PrintStream;

import rice.environment.logging.Logger;
import rice.environment.time.TimeSource;

/**
 * This logger writes its name:time:message to the printstream provided, unless
 * the priority is lower than the minimumPriority.
 *
 * @version $Id: pretty.settings,v 1.3 2005/03/11 20:22:33 jeffh Exp $
 * @author Jeff Hoye
 */
public class SimpleLogger implements Logger {

  /**
   * The name of this logger.
   */
  String loggerName;

  /**
   * The stream to print to.
   */
  PrintStream ps;

  /**
   * The timesource.
   */
  TimeSource time;

  /**
   * The minimum priority to display.
   */
  int minPriority;

  /**
   * Constructor.
   *
   * @param loggerName the name of this logger.
   * @param ps the stream to print to.
   * @param time the timesource.
   * @param minPriority the minimum priority to display.
   */
  public SimpleLogger(String loggerName, PrintStream ps, TimeSource time, int minPriority) {
    this.loggerName = loggerName;
    this.ps = ps;
    this.time = time;
    this.minPriority = minPriority;
  }

  /**
   * Prints out loggerName:currentTime:message
   *
   * @param priority DESCRIBE THE PARAMETER
   * @param message DESCRIBE THE PARAMETER
   */
  public void log(int priority, String message) {
    if (priority >= minPriority) {
      ps.println(loggerName + ":" + time.currentTimeMillis() + ":" + message);
    }
  }
}
